Index: channels/chan_skinny.c
===================================================================
--- channels/chan_skinny.c	(revision 139009)
+++ channels/chan_skinny.c	(working copy)
@@ -2740,6 +2740,54 @@
 		ast_cli(fd, "none");
 }
 
+static char *handle_skinny_show_debug(struct ast_cli_entry *e, int cmd, struct ast_cli_args *a)
+{
+	struct skinny_device *d;
+	struct skinny_line *l;
+	struct skinny_subchannel *sub;
+
+	switch (cmd) {
+	case CLI_INIT:
+		e->command = "skinny show debug";
+		e->usage =
+			"Usage: skinny show bug\n"
+			"       Lists all devices, lines and subs on the system.\n";
+		return NULL;
+	case CLI_GENERATE:
+		return NULL;
+	}
+
+	if (a->argc != 3)
+		return CLI_SHOWUSAGE;
+
+	ast_cli(a->fd, "Name                 DeviceId         IP              Type            R NL\n");
+	ast_cli(a->fd, "-------------------- ---------------- --------------- --------------- - --\n");
+
+	AST_LIST_LOCK(&devices); 
+	AST_LIST_TRAVERSE(&devices, d, list) {
+		ast_cli(a->fd, "%s(%s)  IP:%s Type:%s\n",
+			d->name,
+			d->id,
+			d->session?ast_inet_ntoa(d->session->sin.sin_addr):"",
+			device2str(d->type));
+		AST_LIST_TRAVERSE(&d->lines, l, list) {
+			ast_cli(a->fd, "   - %d(%s) hook(%d) cwait(%d) xfer(%d)\n",
+				l->instance,
+				l->name,
+				l->hookstate,
+				l->callwaiting,
+				l->transfer);
+			AST_LIST_TRAVERSE(&l->sub, sub, list) {
+				ast_cli(a->fd, "      %s> %s to %s\n",
+					(sub==l->activesub?"A":" "),
+					sub->owner->name,
+					(ast_bridged_channel(sub->owner)?ast_bridged_channel(sub->owner)->name:""));
+			}
+		}
+	}
+	AST_LIST_UNLOCK(&devices);
+	return CLI_SUCCESS;
+}
 static char *handle_skinny_show_devices(struct ast_cli_entry *e, int cmd, struct ast_cli_args *a)
 {
 	struct skinny_device *d;
@@ -2993,6 +3041,7 @@
 
 static struct ast_cli_entry cli_skinny_set_debug_deprecated = AST_CLI_DEFINE(handle_skinny_set_debug_deprecated, "Enable/Disable Skinny debugging");
 static struct ast_cli_entry cli_skinny[] = {
+	AST_CLI_DEFINE(handle_skinny_show_debug, "Provide a list for debugging"),
 	AST_CLI_DEFINE(handle_skinny_show_devices, "List defined Skinny devices"),
 	AST_CLI_DEFINE(handle_skinny_show_device, "List Skinny device information"),
 	AST_CLI_DEFINE(handle_skinny_show_lines, "List defined Skinny lines per device"),
@@ -4377,6 +4426,7 @@
 		if (!l) {
 			return 0;
 		}
+		sub = l->activesub;
 	} else {
 		l = sub->parent;
 	}
